@@ -155,6 +155,14 @@ class Key(Enum):
     D8 = 31
 
 
+class KeyAction(Enum):
+    """Action types for LCN keys."""
+
+    HIT = "hit"
+    MAKE = "make"
+    BREAK = "break"
+
+
 class OutputPortDimMode(Enum):
     """LCN dimming mode.
 
@@ -775,7 +783,7 @@ class VarValue:
         elif unit == VarUnit.VOLT:
             var_value = VarValue.from_volt(value)
         elif unit == VarUnit.AMPERE:
-            var_value = VarValue.from_kelvin(value)
+            var_value = VarValue.from_ampere(value)
         elif unit == VarUnit.DEGREE:
             var_value = VarValue.from_degree(value)
         else:
@@ -927,7 +935,7 @@ class VarValue:
         :return: The variable value (never null)
         :rtype:    VarValue
         """
-        return VarValue(int(round(value * 100)))
+        return VarValue(int(round(value * 100000)))
 
     @staticmethod
     def from_degree(value: float, is_abs: bool = True) -> "VarValue":
@@ -1077,7 +1085,7 @@ class VarValue:
         :return:    The converted value
         :rtype:    float
         """
-        return self.native_value / 100.0
+        return self.native_value / 100000.0
 
     def to_degree(self) -> float:
         """Convert to degree value.
@@ -1364,6 +1372,14 @@ def hw_type_new(cls, value):
 setattr(HardwareType, "__new__", hw_type_new)
 
 
+class AccessControlPeriphery(Enum):
+    """Action types for LCN keys."""
+
+    TRANSMITTER = "transmitter"
+    TRANSPONDER = "transponder"
+    FINGERPRINT = "fingerprint"
+
+
 default_connection_settings: Dict[str, Any] = {
     "NUM_TRIES": 3,  # Total number of request to sent before going into
     # failed-state.
